toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final name = element.name;

  builder
    ..name = name.withMixinName
    ..on = Reference('VibeObserver, VibeContainerProvider')
    ..methods.add(
      Method(
        (builder) => builder
          ..returns = Reference(name.wrapperClassName)
          ..type = MethodType.getter
          ..name = '\$${name.camelCase}'
          ..body = Code('''
return ${name.repositoryName}.find(\$container, this);
'''),
      ),
    );

  return builder.build().accept(_emitter).toString();
}